diff --git a/index.html b/index.html
index 429a991c3c..e38e4de77c 100644
--- a/index.html
+++ b/index.html
@@ -25,7 +25,7 @@
display: block !important;
}
-
+
diff --git a/74873.a86ee4b5.async.js b/74873.d38a9310.async.js
similarity index 99%
rename from 74873.a86ee4b5.async.js
rename to 74873.d38a9310.async.js
index 502192c4bd..c0e9c848f9 100644
--- a/74873.a86ee4b5.async.js
+++ b/74873.d38a9310.async.js
@@ -606,10 +606,11 @@ __webpack_require__.d(__webpack_exports__, {
d0: function() { return /* binding */ disabledTime; },
MI: function() { return /* binding */ handleCloseOrOpenModal; },
_l: function() { return /* binding */ handleTreeData; },
+ GJ: function() { return /* binding */ isAdmin; },
G5: function() { return /* binding */ isAdminOrTeacher; }
});
// UNUSED EXPORTS: range
// EXTERNAL MODULE: ./node_modules/_react@17.0.2@react/index.js
var _react_17_0_2_react = __webpack_require__(59301);
@@ -765,6 +766,14 @@ var getLegalAuth = function getLegalAuth(auth) {
var isAdminOrTeacher = function isAdminOrTeacher() {
return getLegalAuth([LegalRoleType.Admin, LegalRoleType.Teacher]);
};
+// 管理员
+var isAdmin = function isAdmin() {
+ return getLegalAuth([LegalRoleType.Admin]);
+};
+// 老师
+var isTeacher = function isTeacher() {
+ return getLegalAuth([LegalRoleType.Teacher]);
+};
/***/ })
@@ -606,10 +606,11 @@ __webpack_require__.d(__webpack_exports__, {
G5: function() { return /* binding */ isAdminOrTeacher; }
});
-// UNUSED EXPORTS: range
+// UNUSED EXPORTS: isTeacher, range
// EXTERNAL MODULE: ./node_modules/_react@17.0.2@react/index.js
var _react_17_0_2_react = __webpack_require__(59301);